<?php

global $tooltips;

$tooltips=array();

$tooltips['sfusinglinking']= 'If you are using the blog linking between your blog and the forum, you must check this option.';

$tooltips['sfusinglinkcomments']= 'If you are using the blog linking between your blog comments and the forum, you must check this option.';

$tooltips['sfusingwidgets']= 'If you are using the SPF Widet for diplaying the latest topics in the forum, you must check this option.';

$tooltips['sfusinggeneraltags']= 'If you are using any of the SPF general template tags: <b>sf_sidedash_tag()</b>, <b>sf_admin_mod_status()</b>, or <b>sf_new_posts_tag()</b>, you must check this option.';

$tooltips['sfusingavatartags']= 'If you are using any of the SPF avatar template tags: <b>sf_show_avatar()</b>, <b>sf_show_members_avatar()</b>, or <b>sf_show_forum_avatar()</b>, you must check this option.';

$tooltips['sfusingliststags']= 'If you are using any of the SPF list template tags: <b>sf_recent_posts_tag()</b>, <b>sf_recent_posts_alt_tag()</b>, <b>sf_latest_posts()</b>, <b>sf_new_post_announce()</b>, <b>sf_hot_topics()</b>, <b>sf_author_posts()</b>, <b>sf_highest_rated_posts()</b>, <b>sf_most_rated_posts()</b>, or <b>sf_recent_posts_expanded()</b>, you must check this option.';

$tooltips['sfusingtagstags']= 'If you are using any of the SPF tags template tags: <b>sf_most_used_tags()</b>, <b>sf_tag_cloud()</b>, or <b>sf_related_topics()</b>, you must check this option.';

$tooltips['sfusingpagestags']= 'If you are using any of the SPF page template tags: <b>sf_is_groupview()</b>, <b>sf_is_forumview()</b>, <b>sf_is_topicview()</b>, <b>sf_is_profileview()</b>, <b>sf_is_pmview()</b>, <b>sf_is_listview()</b>, <b>sf_is_searchview()</b>, or <b>sf_is_forumpage()</b>, you must check this option.';

$tooltips['sfusingpmtags']= 'If you are using any of the SPF PM template tags: <b>sf_pm_tag()</b>, or <b>sf_sendpm_tag()</b>, you must check this option.';

$tooltips['sfusingstatstags']= 'If you are using the SPF stats template tag <b>sf_stats_tag()</b>, you must check this option.';

$tooltips['sfusinglinkstags']= 'If you are using any of the SPF links template tags: <b>sf_forum_homelink()</b>, <b>sf_group_link()</b>, <b>sf_forum_link()</b>, <b>sf_topic_link()</b>, <b>sf_forum_dropdown()</b>, <b>sf_add_new_topic_tag()</b> or <b>sf_add_new_topic_tag()</b>, you must check this option.';

?>